@@ -143,10 +143,6 @@ sub NOFFCHECK () { return 0x2; }
 sub FRESHREPO () { return 0x4; }
 sub NOCOMMITCHECK () { return 0x8; }
 
-our $negate_harmful_gitattrs =
-    "-text -eol -crlf -ident -filter -working-tree-encoding";
-    # ^ when updating this, alter the regexp in dgit:is_gitattrs_setup
-
 our $forkcheck_mainprocess;
 
 sub forkcheck_setup () {
@@ -789,7 +785,7 @@ sub reflog_cache_insert ($$$) {
 	my $tree = cmdoutput qw(git rev-parse), "$value:";
 	# git update-ref doesn't always update, in this case.  *sigh*
 	my $authline = (ucfirst _us()).
-	    ' <'._us().'@example.com> 1000000000 +0000';
+	    ' <'._us().'@usr.bin.invalid> 1000000000 +0000';
 	my $dummy = hash_commit_text <<ENDU.(__ <<END);
 tree $tree
 parent $value
